@@ -8,11 +8,22 @@ from more_itertools import unique_everseen
 from matplotlib.cm import get_cmap
 from matplotlib.path import Path
 
-from .geometry import (circos_radius, get_cartesian, node_theta, group_theta,
-                       text_alignment)
+from .geometry import (
+    circos_radius,
+    get_cartesian,
+    node_theta,
+    group_theta,
+    text_alignment,
+)
 from .polcart import to_degrees
-from .utils import (cmaps, infer_data_type, is_data_diverging,
-                    num_discrete_groups, n_group_colorpallet, items_in_groups)
+from .utils import (
+    cmaps,
+    infer_data_type,
+    is_data_diverging,
+    num_discrete_groups,
+    n_group_colorpallet,
+    items_in_groups,
+)
 
 
 def despine(ax):
@@ -77,13 +88,26 @@ class BasePlot(object):
     :param edgeprops: A `matplotlib-compatible `props` dictioanry.
     :type edgeprops: `dict`
     """  # noqa
-    def __init__(self, graph, node_order=None, node_size=None,
-                 node_grouping=None, group_order="alphabetically",
-                 node_color=None, node_labels=None, edge_width=None,
-                 edge_color=None, data_types=None, nodeprops=None,
-                 edgeprops=None, node_label_color=False,
-                 group_label_position=None, group_label_color=False,
-                 **kwargs):
+
+    def __init__(
+        self,
+        graph,
+        node_order=None,
+        node_size=None,
+        node_grouping=None,
+        group_order="alphabetically",
+        node_color=None,
+        node_labels=None,
+        edge_width=None,
+        edge_color=None,
+        data_types=None,
+        nodeprops=None,
+        edgeprops=None,
+        node_label_color=False,
+        group_label_position=None,
+        group_label_color=False,
+        **kwargs
+    ):
         super(BasePlot, self).__init__()
         # Set graph object
         self.graph = graph
@@ -100,13 +124,15 @@ class BasePlot(object):
 
         # Set node colors
         self.node_color = node_color
-        self.sm = None  # sm -> for scalarmappable. See https://stackoverflow.com/questions/8342549/matplotlib-add-colorbar-to-a-sequence-of-line-plots  # noqa
-        logging.debug('INIT: {0}'.format(self.sm))
+        self.sm = (
+            None
+        )  # sm -> for scalarmappable. See https://stackoverflow.com/questions/8342549/matplotlib-add-colorbar-to-a-sequence-of-line-plots  # noqa
+        logging.debug("INIT: {0}".format(self.sm))
         if self.node_color:
             self.node_colors = []
             self.compute_node_colors()
         else:
-            self.node_colors = ['blue'] * len(self.nodes)
+            self.node_colors = ["blue"] * len(self.nodes)
         self.node_labels = node_labels
 
         # Set edge properties
@@ -116,7 +142,7 @@ class BasePlot(object):
             self.edge_colors = []
             self.compute_edge_colors()
         else:
-            self.edge_colors = ['black'] * len(self.edges)
+            self.edge_colors = ["black"] * len(self.edges)
 
         # Set data_types dictionary
         if not data_types:
@@ -126,8 +152,8 @@ class BasePlot(object):
             self.data_types = data_types
 
         figsize = (6, 6)
-        if 'figsize' in kwargs.keys():
-            figsize = kwargs['figsize']
+        if "figsize" in kwargs.keys():
+            figsize = kwargs["figsize"]
         self.figure = plt.figure(figsize=figsize)
         self.ax = self.figure.add_subplot(1, 1, 1)
         despine(self.ax)
@@ -137,18 +163,17 @@ class BasePlot(object):
         if nodeprops:
             self.nodeprops = nodeprops
         else:
-            self.nodeprops = {'radius': 1}
+            self.nodeprops = {"radius": 1}
         # edgeprops are matplotlib line properties. These can be set after
         # instantiation but before calling the draw() function.
         if edgeprops:
             self.edgeprops = edgeprops
         else:
-            self.edgeprops = {'facecolor': 'none',
-                              'alpha': 0.2}
+            self.edgeprops = {"facecolor": "none", "alpha": 0.2}
         if node_label_color:
             self.node_label_color = self.node_colors
         else:
-            self.node_label_color = ['black'] * len(self.nodes)
+            self.node_label_color = ["black"] * len(self.nodes)
 
         # Compute each node's positions.
         self.compute_node_positions()
@@ -164,7 +189,7 @@ class BasePlot(object):
             if group_label_color:
                 self.compute_group_colors()
             else:
-                self.group_label_color = ['black'] * len(self.nodes)
+                self.group_label_color = ["black"] * len(self.nodes)
 
     def check_data_types(self, data_types):
         """
@@ -176,7 +201,7 @@ class BasePlot(object):
         :type data_types: `dict`
         """
         for k, v in data_types.items():
-            assert v in ['ordinal', 'categorical', 'continuous']
+            assert v in ["ordinal", "categorical", "continuous"]
 
     def draw(self):
         """
@@ -191,16 +216,16 @@ class BasePlot(object):
         self.draw_edges()
         # note that self.groups only exists on condition
         # that group_label_position was given!
-        if hasattr(self, 'groups') and self.groups:
+        if hasattr(self, "groups") and self.groups:
             self.draw_group_labels()
-        logging.debug('DRAW: {0}'.format(self.sm))
+        logging.debug("DRAW: {0}".format(self.sm))
         if self.sm:
             self.figure.subplots_adjust(right=0.8)
             cax = self.figure.add_axes([0.85, 0.2, 0.05, 0.6])
             self.figure.colorbar(self.sm, cax=cax)
         self.ax.relim()
         self.ax.autoscale_view()
-        self.ax.set_aspect('equal')
+        self.ax.set_aspect("equal")
 
     def compute_node_colors(self):
         """Compute the node colors. Also computes the colorbar."""
@@ -214,37 +239,41 @@ class BasePlot(object):
         dtype = infer_data_type(data)
         n_grps = num_discrete_groups(data)
 
-        if dtype == 'categorical' or dtype == 'ordinal':
+        if dtype == "categorical" or dtype == "ordinal":
             if n_grps <= 8:
-                cmap = \
-                    get_cmap(cmaps['Accent_{0}'.format(n_grps)].mpl_colormap)
+                cmap = get_cmap(
+                    cmaps["Accent_{0}".format(n_grps)].mpl_colormap
+                )
             else:
                 cmap = n_group_colorpallet(n_grps)
-        elif dtype == 'continuous' and not is_data_diverging(data):
-            cmap = get_cmap(cmaps['continuous'].mpl_colormap)
-        elif dtype == 'continuous' and is_data_diverging(data):
-            cmap = get_cmap(cmaps['diverging'].mpl_colormap)
+        elif dtype == "continuous" and not is_data_diverging(data):
+            cmap = get_cmap(cmaps["continuous"].mpl_colormap)
+        elif dtype == "continuous" and is_data_diverging(data):
+            cmap = get_cmap(cmaps["diverging"].mpl_colormap)
 
         for d in data:
             idx = data_reduced.index(d) / n_grps
             self.node_colors.append(cmap(idx))
 
         # Add colorbar if required.ListedColormap
-        logging.debug('length of data_reduced: {0}'.format(len(data_reduced)))
-        logging.debug('dtype: {0}'.format(dtype))
-        if len(data_reduced) > 1 and dtype == 'continuous':
-            self.sm = plt.cm.ScalarMappable(cmap=cmap,
-                                            norm=plt.Normalize(vmin=min(data_reduced),  # noqa
-                                                               vmax=max(data_reduced)   # noqa
-                                                               )
-                                            )
+        logging.debug("length of data_reduced: {0}".format(len(data_reduced)))
+        logging.debug("dtype: {0}".format(dtype))
+        if len(data_reduced) > 1 and dtype == "continuous":
+            self.sm = plt.cm.ScalarMappable(
+                cmap=cmap,
+                norm=plt.Normalize(
+                    vmin=min(data_reduced),
+                    vmax=max(data_reduced),  # noqa  # noqa
+                ),
+            )
             self.sm._A = []
 
     def compute_group_colors(self):
         """Computes the group colors according to node colors"""
         seen = set()
-        self.group_label_color = \
-            [x for x in self.node_colors if not (x in seen or seen.add(x))]
+        self.group_label_color = [
+            x for x in self.node_colors if not (x in seen or seen.add(x))
+        ]
 
     def compute_edge_colors(self):
         """Compute the edge colors."""
@@ -253,27 +282,30 @@ class BasePlot(object):
 
         dtype = infer_data_type(data)
         n_grps = num_discrete_groups(data)
-        if dtype == 'categorical' or dtype == 'ordinal':
+        if dtype == "categorical" or dtype == "ordinal":
             if n_grps <= 8:
-                cmap = \
-                    get_cmap(cmaps['Accent_{0}'.format(n_grps)].mpl_colormap)
+                cmap = get_cmap(
+                    cmaps["Accent_{0}".format(n_grps)].mpl_colormap
+                )
             else:
                 cmap = n_group_colorpallet(n_grps)
-        elif dtype == 'continuous' and not is_data_diverging(data):
-            cmap = get_cmap(cmaps['weights'])
+        elif dtype == "continuous" and not is_data_diverging(data):
+            cmap = get_cmap(cmaps["weights"])
 
         for d in data:
             idx = data_reduced.index(d) / n_grps
             self.edge_colors.append(cmap(idx))
         # Add colorbar if required.
-        logging.debug('length of data_reduced: {0}'.format(len(data_reduced)))
-        logging.debug('dtype: {0}'.format(dtype))
-        if len(data_reduced) > 1 and dtype == 'continuous':
-            self.sm = plt.cm.ScalarMappable(cmap=cmap,
-                                            norm=plt.Normalize(vmin=min(data_reduced),  # noqa
-                                                               vmax=max(data_reduced)   # noqa
-                                                               )
-                                            )
+        logging.debug("length of data_reduced: {0}".format(len(data_reduced)))
+        logging.debug("dtype: {0}".format(dtype))
+        if len(data_reduced) > 1 and dtype == "continuous":
+            self.sm = plt.cm.ScalarMappable(
+                cmap=cmap,
+                norm=plt.Normalize(
+                    vmin=min(data_reduced),
+                    vmax=max(data_reduced),  # noqa  # noqa
+                ),
+            )
             self.sm._A = []
 
     def compute_group_label_positions(self):
@@ -333,41 +365,70 @@ class BasePlot(object):
         """
         if self.node_grouping and not self.node_order:
             if self.group_order == "alphabetically":
-                self.nodes = [n for n, d in
-                              sorted(self.graph.nodes(data=True),
-                                     key=lambda x: x[1][self.node_grouping])]
+                self.nodes = [
+                    n
+                    for n, d in sorted(
+                        self.graph.nodes(data=True),
+                        key=lambda x: x[1][self.node_grouping],
+                    )
+                ]
 
             elif self.group_order == "default":
-                grp = [d[self.node_grouping] for _, d
-                       in self.graph.nodes(data=True)]
+                grp = [
+                    d[self.node_grouping]
+                    for _, d in self.graph.nodes(data=True)
+                ]
                 grp_name = list(unique_everseen(grp))
                 nodes = []
                 for key in grp_name:
-                    nodes.extend([n for n, d in self.graph.nodes(data=True)
-                                  if key in d.values()])
+                    nodes.extend(
+                        [
+                            n
+                            for n, d in self.graph.nodes(data=True)
+                            if key in d.values()
+                        ]
+                    )
                 self.nodes = nodes
 
         elif self.node_order and not self.node_grouping:
-            self.nodes = [n for n, _ in
-                          sorted(self.graph.nodes(data=True),
-                                 key=lambda x: x[1][self.node_order])]
+            self.nodes = [
+                n
+                for n, _ in sorted(
+                    self.graph.nodes(data=True),
+                    key=lambda x: x[1][self.node_order],
+                )
+            ]
 
         elif self.node_grouping and self.node_order:
             if self.group_order == "alphabetically":
-                self.nodes = [n for n, d in
-                              sorted(self.graph.nodes(data=True),
-                                     key=lambda x: (x[1][self.node_grouping],
-                                                    x[1][self.node_order]))]
+                self.nodes = [
+                    n
+                    for n, d in sorted(
+                        self.graph.nodes(data=True),
+                        key=lambda x: (
+                            x[1][self.node_grouping],
+                            x[1][self.node_order],
+                        ),
+                    )
+                ]
             elif self.group_order == "default":
-                grp = [d[self.node_grouping] for _, d
-                       in self.graph.nodes(data=True)]
+                grp = [
+                    d[self.node_grouping]
+                    for _, d in self.graph.nodes(data=True)
+                ]
                 grp_name = list(unique_everseen(grp))
                 nodes = []
                 for key in grp_name:
-                    nodes.extend([n for n, d in
-                                  sorted(self.graph.nodes(data=True),
-                                         key=lambda x:x[1][self.node_order])
-                                  if key in d.values()])
+                    nodes.extend(
+                        [
+                            n
+                            for n, d in sorted(
+                                self.graph.nodes(data=True),
+                                key=lambda x: x[1][self.node_order],
+                            )
+                            if key in d.values()
+                        ]
+                    )
                 self.nodes = nodes
 
 
@@ -390,7 +451,7 @@ class CircosPlot(BasePlot):
         # Node labels are specified in the node_label_layout argument
         specified_layout = kwargs.pop("node_label_layout", None)
         # Verify that the provided input is legitimate
-        valid_node_label_layouts = (None, 'rotation', 'numbers')
+        valid_node_label_layouts = (None, "rotation", "numbers")
         assert specified_layout in valid_node_label_layouts
         # Store the noda label layout
         self.node_label_layout = specified_layout
@@ -406,7 +467,7 @@ class CircosPlot(BasePlot):
         data = [self.graph.node[n][self.node_grouping] for n in self.nodes]
         node_length = len(data)
         groups = items_in_groups(data)
-        radius = 1.02 * (self.plot_radius + self.nodeprops['radius'])
+        radius = 1.02 * (self.plot_radius + self.nodeprops["radius"])
         xs = []
         ys = []
         has = []
@@ -415,8 +476,9 @@ class CircosPlot(BasePlot):
         node_idcs = np.insert(node_idcs, 0, 0)
         if self.group_label_position == "beginning":
             for idx in node_idcs[:-1]:
-                x, y = get_cartesian(r=radius, theta=group_theta(node_length,
-                                                                 idx))
+                x, y = get_cartesian(
+                    r=radius, theta=group_theta(node_length, idx)
+                )
                 ha, va = text_alignment(x, y)
                 xs.append(x)
                 ys.append(y)
@@ -428,8 +490,8 @@ class CircosPlot(BasePlot):
             node_idcs = np.concatenate((node_idcs[:-1], node_idcs[1:]), axis=1)
             for idx in node_idcs:
                 theta1 = group_theta(node_length, idx[0])
-                theta2 = group_theta(node_length, idx[1]-1)
-                x, y = get_cartesian(r=radius, theta=(theta1+theta2)/2)
+                theta2 = group_theta(node_length, idx[1] - 1)
+                x, y = get_cartesian(r=radius, theta=(theta1 + theta2) / 2)
                 ha, va = text_alignment(x, y)
                 xs.append(x)
                 ys.append(y)
@@ -438,16 +500,17 @@ class CircosPlot(BasePlot):
 
         elif self.group_label_position == "end":
             for idx in node_idcs[1::]:
-                x, y = get_cartesian(r=radius, theta=group_theta(node_length,
-                                                                 idx-1))
+                x, y = get_cartesian(
+                    r=radius, theta=group_theta(node_length, idx - 1)
+                )
                 ha, va = text_alignment(x, y)
                 xs.append(x)
                 ys.append(y)
                 has.append(ha)
                 vas.append(va)
 
-        self.group_label_coords = {'x': xs, 'y': ys}
-        self.group_label_aligns = {'has': has, 'vas': vas}
+        self.group_label_coords = {"x": xs, "y": ys}
+        self.group_label_aligns = {"has": has, "vas": vas}
         self.groups = groups.keys()
 
     def compute_node_positions(self):
@@ -457,15 +520,15 @@ class CircosPlot(BasePlot):
         """
         xs = []
         ys = []
-        node_r = self.nodeprops['radius']
+        node_r = self.nodeprops["radius"]
         radius = circos_radius(n_nodes=len(self.graph.nodes()), node_r=node_r)
         self.plot_radius = radius
-        self.nodeprops['linewidth'] = radius * 0.01
+        self.nodeprops["linewidth"] = radius * 0.01
         for node in self.nodes:
             x, y = get_cartesian(r=radius, theta=node_theta(self.nodes, node))
             xs.append(x)
             ys.append(y)
-        self.node_coords = {'x': xs, 'y': ys}
+        self.node_coords = {"x": xs, "y": ys}
 
     def compute_node_label_positions(self):
         """
@@ -486,11 +549,11 @@ class CircosPlot(BasePlot):
             # Define radius 'radius' and circumference 'theta'
             theta = node_theta(self.nodes, node)
             # multiplication factor 1.02 moved below
-            radius = self.plot_radius + self.nodeprops['radius']
+            radius = self.plot_radius + self.nodeprops["radius"]
 
             # Coordinates of text inside nodes
-            if self.node_label_layout == 'numbers':
-                radius_adjustment = (1.0 - (1.0/radius))
+            if self.node_label_layout == "numbers":
+                radius_adjustment = 1.0 - (1.0 / radius)
             else:
                 radius_adjustment = 1.02
             x, y = get_cartesian(r=radius * radius_adjustment, theta=theta)
@@ -505,10 +568,11 @@ class CircosPlot(BasePlot):
             tx += self.nonzero_sign(x)
 
             # Node label y-axis coordinate numerator
-            numerator = radius * \
-                (theta % (self.nonzero_sign(y)*self.nonzero_sign(x)*np.pi))
+            numerator = radius * (
+                theta % (self.nonzero_sign(y) * self.nonzero_sign(x) * np.pi)
+            )
             # Node label y-axis coordinate denominator
-            denominator = (self.nonzero_sign(x)*np.pi)
+            denominator = self.nonzero_sign(x) * np.pi
             # Node label y-axis coordinate
             ty = 2 * (numerator / denominator)
 
@@ -516,7 +580,7 @@ class CircosPlot(BasePlot):
 
             # Computes the text rotation
             theta_deg = to_degrees(theta)
-            if theta_deg >= -90 and theta_deg < 90:   # right side
+            if theta_deg >= -90 and theta_deg < 90:  # right side
                 rot = theta_deg
             else:  # left side
                 rot = theta_deg - 180
@@ -539,8 +603,8 @@ class CircosPlot(BasePlot):
         """
 
         # Reset node label coorc/align dictionaries
-        self.node_label_coords = {'x': [], 'y': [], 'tx': [], 'ty': []}
-        self.node_label_aligns = {'has': [], 'vas': []}
+        self.node_label_coords = {"x": [], "y": [], "tx": [], "ty": []}
+        self.node_label_aligns = {"has": [], "vas": []}
         self.node_label_rotation = []
 
     def store_node_label_meta(self, x, y, tx, ty, rot):
@@ -565,26 +629,26 @@ class CircosPlot(BasePlot):
         """
 
         # Store computed values
-        self.node_label_coords['x'].append(x)
-        self.node_label_coords['y'].append(y)
-        self.node_label_coords['tx'].append(tx)
-        self.node_label_coords['ty'].append(ty)
+        self.node_label_coords["x"].append(x)
+        self.node_label_coords["y"].append(y)
+        self.node_label_coords["tx"].append(tx)
+        self.node_label_coords["ty"].append(ty)
 
         # Computes the text alignment for x
         if x == 0:
-            self.node_label_aligns['has'].append('center')
+            self.node_label_aligns["has"].append("center")
         elif x > 0:
-            self.node_label_aligns['has'].append('left')
+            self.node_label_aligns["has"].append("left")
         else:
-            self.node_label_aligns['has'].append('right')
+            self.node_label_aligns["has"].append("right")
 
         # Computes the text alignment for y
-        if self.node_label_layout == 'rotate' or y == 0:
-            self.node_label_aligns['vas'].append('center')
+        if self.node_label_layout == "rotate" or y == 0:
+            self.node_label_aligns["vas"].append("center")
         elif y > 0:
-            self.node_label_aligns['vas'].append('bottom')
+            self.node_label_aligns["vas"].append("bottom")
         else:
-            self.node_label_aligns['vas'].append('top')
+            self.node_label_aligns["vas"].append("top")
 
         self.node_label_rotation.append(rot)
 
@@ -592,56 +656,73 @@ class CircosPlot(BasePlot):
         """
         Renders nodes to the figure.
         """
-        node_r = self.nodeprops['radius']
-        lw = self.nodeprops['linewidth']
+        node_r = self.nodeprops["radius"]
+        lw = self.nodeprops["linewidth"]
         for i, node in enumerate(self.nodes):
-            x = self.node_coords['x'][i]
-            y = self.node_coords['y'][i]
+            x = self.node_coords["x"][i]
+            y = self.node_coords["y"][i]
             color = self.node_colors[i]
-            node_patch = patches.Circle((x, y), node_r,
-                                        lw=lw, color=color,
-                                        zorder=2)
+            node_patch = patches.Circle(
+                (x, y), node_r, lw=lw, color=color, zorder=2
+            )
             self.ax.add_patch(node_patch)
             if self.node_labels:
-                label_x = self.node_label_coords['x'][i]
-                label_y = self.node_label_coords['y'][i]
-                label_tx = self.node_label_coords['tx'][i]
-                label_ty = self.node_label_coords['ty'][i]
-                label_ha = self.node_label_aligns['has'][i]
-                label_va = self.node_label_aligns['vas'][i]
+                label_x = self.node_label_coords["x"][i]
+                label_y = self.node_label_coords["y"][i]
+                label_tx = self.node_label_coords["tx"][i]
+                label_ty = self.node_label_coords["ty"][i]
+                label_ha = self.node_label_aligns["has"][i]
+                label_va = self.node_label_aligns["vas"][i]
 
                 # ----- Node label rotation layout -----
 
-                if self.node_label_layout == 'rotation':
+                if self.node_label_layout == "rotation":
                     rot = self.node_label_rotation[i]
 
-                    self.ax.text(s=node,
-                                 x=label_x, y=label_y,
-                                 ha=label_ha, va=label_va, rotation=rot,
-                                 rotation_mode="anchor",
-                                 color=self.node_label_color[i], fontsize=10)
+                    self.ax.text(
+                        s=node,
+                        x=label_x,
+                        y=label_y,
+                        ha=label_ha,
+                        va=label_va,
+                        rotation=rot,
+                        rotation_mode="anchor",
+                        color=self.node_label_color[i],
+                        fontsize=10,
+                    )
 
                 # ----- Node label numbering layout -----
 
-                elif self.node_label_layout == 'numbers':
+                elif self.node_label_layout == "numbers":
 
                     # Draw descriptions for labels
-                    desc = '%s - %s' % ((i, node) if (x > 0) else (node, i))
-                    self.ax.text(s=desc, x=label_tx,
-                                 y=label_ty, ha=label_ha,
-                                 va=label_va, color=self.node_label_color[i])
+                    desc = "%s - %s" % ((i, node) if (x > 0) else (node, i))
+                    self.ax.text(
+                        s=desc,
+                        x=label_tx,
+                        y=label_ty,
+                        ha=label_ha,
+                        va=label_va,
+                        color=self.node_label_color[i],
+                    )
 
                     # Add numbers to nodes
-                    self.ax.text(s=i, x=label_x, y=label_y,
-                                 ha='center', va='center')
+                    self.ax.text(
+                        s=i, x=label_x, y=label_y, ha="center", va="center"
+                    )
 
                 # Standard node label layout
                 else:
 
                     # Draw node text straight from the nodes
-                    self.ax.text(s=node, x=label_x,
-                                 y=label_y, ha=label_ha,
-                                 va=label_va, color=self.node_label_color[i])
+                    self.ax.text(
+                        s=node,
+                        x=label_x,
+                        y=label_y,
+                        ha=label_ha,
+                        va=label_va,
+                        color=self.node_label_color[i],
+                    )
 
     def draw_edges(self):
         """
@@ -650,14 +731,17 @@ class CircosPlot(BasePlot):
         for i, (start, end) in enumerate(self.graph.edges()):
             start_theta = node_theta(self.nodes, start)
             end_theta = node_theta(self.nodes, end)
-            verts = [get_cartesian(self.plot_radius, start_theta),
-                     (0, 0),
-                     get_cartesian(self.plot_radius, end_theta)]
+            verts = [
+                get_cartesian(self.plot_radius, start_theta),
+                (0, 0),
+                get_cartesian(self.plot_radius, end_theta),
+            ]
             color = self.edge_colors[i]
             codes = [Path.MOVETO, Path.CURVE3, Path.CURVE3]
             path = Path(verts, codes)
-            patch = patches.PathPatch(path, lw=1, edgecolor=color,
-                                      zorder=1, **self.edgeprops)
+            patch = patches.PathPatch(
+                path, lw=1, edgecolor=color, zorder=1, **self.edgeprops
+            )
             self.ax.add_patch(patch)
 
     def draw_group_labels(self):
@@ -665,15 +749,20 @@ class CircosPlot(BasePlot):
         Renders group labels to the figure.
         """
         for i, label in enumerate(self.groups):
-            label_x = self.group_label_coords['x'][i]
-            label_y = self.group_label_coords['y'][i]
-            label_ha = self.group_label_aligns['has'][i]
-            label_va = self.group_label_aligns['vas'][i]
+            label_x = self.group_label_coords["x"][i]
+            label_y = self.group_label_coords["y"][i]
+            label_ha = self.group_label_aligns["has"][i]
+            label_va = self.group_label_aligns["vas"][i]
             color = self.group_label_color[i]
-            self.ax.text(s=label,
-                         x=label_x, y=label_y,
-                         ha=label_ha, va=label_va,
-                         color=color)
+            self.ax.text(
+                s=label,
+                x=label_x,
+                y=label_y,
+                ha=label_ha,
+                va=label_va,
+                color=color,
+            )
+
 
 # class HivePlot(BasePlot):
 #     """
@@ -824,20 +913,38 @@ class MatrixPlot(BasePlot):
     """
     Plotting object for the MatrixPlot.
     """
-    def __init__(self, graph, node_order=None, node_size=None,
-                 node_grouping=None, node_color=None, edge_width=None,
-                 edge_color=None, data_types=None, nodeprops=None,
-                 edgeprops=None):
+
+    def __init__(
+        self,
+        graph,
+        node_order=None,
+        node_size=None,
+        node_grouping=None,
+        node_color=None,
+        edge_width=None,
+        edge_color=None,
+        data_types=None,
+        nodeprops=None,
+        edgeprops=None,
+    ):
 
         # Initialize using BasePlot
-        BasePlot.__init__(self, graph, node_order=node_order,
-                          node_size=node_size, node_grouping=node_grouping,
-                          node_color=node_color, edge_width=edge_width,
-                          edge_color=edge_color, data_types=data_types,
-                          nodeprops=nodeprops, edgeprops=edgeprops)
+        BasePlot.__init__(
+            self,
+            graph,
+            node_order=node_order,
+            node_size=node_size,
+            node_grouping=node_grouping,
+            node_color=node_color,
+            edge_width=edge_width,
+            edge_color=edge_color,
+            data_types=data_types,
+            nodeprops=nodeprops,
+            edgeprops=edgeprops,
+        )
 
         # The following atribute is specific to MatrixPlots
-        self.cmap = cmaps['continuous'].mpl_colormap
+        self.cmap = cmaps["continuous"].mpl_colormap
 
     def draw(self):
         """
@@ -871,7 +978,7 @@ class ArcPlot(BasePlot):
             xs.append(self.nodes.index(node))
             ys.append(0)
 
-        self.node_coords = {'x': xs, 'y': ys}
+        self.node_coords = {"x": xs, "y": ys}
 
     def draw_nodes(self):
         """
@@ -879,11 +986,12 @@ class ArcPlot(BasePlot):
         """
         node_r = 1
         for i, node in enumerate(self.nodes):
-            x = self.node_coords['x'][i]
-            y = self.node_coords['y'][i]
+            x = self.node_coords["x"][i]
+            y = self.node_coords["y"][i]
             color = self.node_colors[i]
-            node_patch = patches.Ellipse((x, y), node_r, node_r,
-                                         lw=0, color=color, zorder=2)
+            node_patch = patches.Ellipse(
+                (x, y), node_r, node_r, lw=0, color=color, zorder=2
+            )
             self.ax.add_patch(node_patch)
 
     def draw_edges(self):
@@ -892,12 +1000,12 @@ class ArcPlot(BasePlot):
         """
         for i, (start, end) in enumerate(self.graph.edges()):
             start_idx = self.nodes.index(start)
-            start_x = self.node_coords['x'][start_idx]
-            start_y = self.node_coords['y'][start_idx]
+            start_x = self.node_coords["x"][start_idx]
+            start_y = self.node_coords["y"][start_idx]
 
             end_idx = self.nodes.index(end)
-            end_x = self.node_coords['x'][end_idx]
-            end_y = self.node_coords['y'][end_idx]
+            end_x = self.node_coords["x"][end_idx]
+            end_y = self.node_coords["y"][end_idx]
 
             arc_radius = abs(end_x - start_x) / 2
             # we do min(start_x, end_x) just in case start_x is greater than
@@ -905,9 +1013,7 @@ class ArcPlot(BasePlot):
             middle_x = min(start_x, end_x) + arc_radius
             middle_y = arc_radius * 2
 
-            verts = [(start_x, start_y),
-                     (middle_x, middle_y),
-                     (end_x, end_y)]
+            verts = [(start_x, start_y), (middle_x, middle_y), (end_x, end_y)]
 
             codes = [Path.MOVETO, Path.CURVE3, Path.CURVE3]
 
